#include <iostream>
#include <cstring>

using namespace std;

const int MAXN = 1e6 + 5;
const long long inf = 1e15 + 5;

int n;
int p[MAXN];
int numPos[MAXN];

struct FenwickTree
{
    int n;
    int tree[MAXN];

    FenwickTree()
    {
        memset(this->tree, 0, sizeof(this->tree));
    }
    FenwickTree(int n) : FenwickTree()
    {
        this->n = n;
    }

    void reset()
    {
        memset(this->tree, 0, sizeof(int)*(n+2));
    }

    void update(int ind, int change)
    {
        ind++;
        while(ind<=n)
        {
            tree[ind] += change;
            ind += ind & (-ind);
        }
    }

    int query(int ind)
    {
        ind++;
        int sum = 0;

        while(ind>0)
        {
            sum += tree[ind];
            ind -= ind & (-ind);
        }

        return sum;
    }

    int query(int l, int r)
    {
        return query(r) - query(l-1);
    }
};

FenwickTree *T = nullptr;
long long eval()
{
    T->reset();

    long long ans = 0;
    for(int i = n;i>=1;i--)
    {
        int pos = numPos[i] - T->query(numPos[i]);

        //for(int j = i+1;j<=n;j++)
        //    if(numPos[j]<numPos[i]) pos--;

        ans += i - 1 - pos;
        T->update(numPos[i], +1);
    }

    return ans;
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    cin >> n;
    for(int i = 0;i<n;i++) cin >> p[i];

    T = new FenwickTree(n);
    for(int i = 0;i<n;i++)
        numPos[p[i]] = i;

    long long ans = inf;
    for(int i = 0;i<n;i++)
    {
        for(int j = i+1;j<n;j++)
        {
            if(p[i]<p[j]) continue;

            swap(numPos[p[i]], numPos[p[j]]);
            ans = min(ans, 1 + eval());
            swap(numPos[p[i]], numPos[p[j]]);
        }
    }

    cout << ans << '\n';
}
