#include <iostream>
#include <cstring>

using namespace std;

const int MAXN = 1e6 + 5;
const long long inf = 1e15 + 5;

int n;
int p[MAXN];
int numPos[MAXN];

struct FenwickTree
{
    int n;
    int tree[MAXN];

    FenwickTree()
    {
        memset(this->tree, 0, sizeof(this->tree));
    }
    FenwickTree(int n) : FenwickTree()
    {
        this->n = n + 2;
    }

    void reset()
    {
        memset(this->tree, 0, sizeof(int)*(n));
    }

    void update(int ind, int change)
    {
        ind++;
        while(ind<=n)
        {
            tree[ind] += change;
            ind += ind & (-ind);
        }
    }

    int query(int ind)
    {
        ind++;
        int sum = 0;

        while(ind>0)
        {
            sum += tree[ind];
            ind -= ind & (-ind);
        }

        return sum;
    }

    int query(int l, int r)
    {
        return query(r) - query(l-1);
    }
};

FenwickTree *T = nullptr;
long long eval()
{
    T->reset();

    long long ans = 0;
    for(int i = n;i>=1;i--)
    {
        int pos = numPos[i] - T->query(numPos[i]);

        //for(int j = i+1;j<=n;j++)
        //    if(numPos[j]<numPos[i]) pos--;

        ans += i - 1 - pos;
        T->update(numPos[i], +1);
    }

    return ans;
}

long long cntInversions()
{
    T->reset();
    long long ans = 0;

    for(int i = n-1;i>=0;i--)
    {
        ans += T->query(p[i]);
        T->update(p[i], +1);
    }

    return ans;

}

int evalChange(int x, int y, pair <int, int> posX, pair <int, int> posY)
{
    if(posX.first<posY.first && posX.second>posY.second) return +1;
    if(posX.first>posY.first && posX.second<posY.second) return -1;
    return 0;
}

int getAdjustment(int x, int other, int newPos)
{
    int change = 0;
    for(int y = 1;y<x;y++)
    {
        if(y==other) continue;
        change += evalChange(x, y, {numPos[x], newPos}, {numPos[y], numPos[y]});
    }

    return change;
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    cin >> n;
    for(int i = 0;i<n;i++) cin >> p[i];

    T = new FenwickTree(n);
    for(int i = 0;i<n;i++)
        numPos[p[i]] = i;

    long long ans = eval();

    long long baseVal = 0;
    for(int i = 1;i<=n;i++)
        baseVal += i - 1 - numPos[i];
    baseVal += cntInversions();

    //cout << baseVal << " == " << eval() << '\n';

    for(int i = 0;i<n;i++)
    {
        for(int j = i+1;j<n;j++)
        {
            if(p[i]<p[j]) continue;

            long long curr = 1 + baseVal;
            for(int ind = i+1;ind<j;ind++)
            {
                if(p[ind]>p[i]) curr++;
                if(p[ind]<p[i]) curr--;

                if(p[ind]>p[j]) curr--;
                if(p[ind]<p[j]) curr++;
            }
            curr--;

            ans = min(ans, curr);
        }
    }

    cout << ans << '\n';
}
